@@ -7,8 +7,7 @@
 #include <QBuffer>
 #include <QIODevice>
 #include <QPointer>
-
-class QWebSocket;
+#include <QWebSocket>
 
 class WebSocketIoDevice : public QIODevice
 {
