@@ -1,5 +1,6 @@
 // Copyright (C) 2017-2015 Ford Motor Company
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
+// Qt-Security score:significant reason:declarations-only
 
 #ifndef QCONNECTIONFACTORIES_P_H
 #define QCONNECTIONFACTORIES_P_H
@@ -24,6 +25,8 @@
 #include <QtRemoteObjects/qconnectionfactories.h>
 #include "qremoteobjectpacket_p.h"
 
+#include <memory>
+
 QT_BEGIN_NAMESPACE
 
 namespace QtRemoteObjects {
@@ -61,7 +64,7 @@ public:
     quint32 m_curReadSize = 0;
     QDataStream m_dataStream;
     QSet<QString> m_remoteObjects;
-    QRemoteObjectPackets::CodecBase *m_codec { nullptr };
+    std::unique_ptr<QRemoteObjectPackets::CodecBase> m_codec { nullptr };
     Q_DECLARE_PUBLIC(QtROIoDeviceBase)
 };
 
