@@ -8,6 +8,7 @@
 #include <qjsondocument.h>
 #include <qjsonobject.h>
 #include <qjsonarray.h>
+#include <qhashfunctions.h>
 
 #include "cppcodegenerator.h"
 #include "repcodegenerator.h"
@@ -29,15 +30,13 @@ enum Mode {
 };
 
 static const QLatin1String REP("rep");
-static const QLatin1String JSON("json");
-static const QLatin1String REPLICA("replica");
-static const QLatin1String SOURCE("source");
-static const QLatin1String MERGED("merged");
 
 QT_USE_NAMESPACE
 
 int main(int argc, char **argv)
 {
+    QHashSeed::setDeterministicGlobalSeed();
+
     QCoreApplication app(argc, argv);
     QCoreApplication::setApplicationVersion(QString::fromLatin1(REPC_VERSION));
 
@@ -97,7 +96,7 @@ int main(int argc, char **argv)
         const QString &inputType = parser.value(inputTypeOption);
         if (inputType == REP)
             mode = InRep;
-        else if (inputType == JSON)
+        else if (inputType == u"json")
             mode = InJson;
         else {
             fprintf(stderr, PROGRAM_NAME ": Unknown input type\"%s\".\n", qPrintable(inputType));
@@ -109,11 +108,11 @@ int main(int argc, char **argv)
         const QString &outputType = parser.value(outputTypeOption);
         if (outputType == REP)
             mode |= OutRep;
-        else if (outputType == REPLICA)
+        else if (outputType == u"replica")
             mode |= OutReplica;
-        else if (outputType == SOURCE)
+        else if (outputType == u"source")
             mode |= OutSource;
-        else if (outputType == MERGED)
+        else if (outputType == u"merged")
             mode |= OutMerged;
         else {
             fprintf(stderr, PROGRAM_NAME ": Unknown output type\"%s\".\n", qPrintable(outputType));
